@@ -841,7 +841,8 @@ class map_manager(map_reader, write_ccp4_map):
     self._created_mask = cm(map_manager = self,
       boundary_radius = boundary_radius)
 
-  def create_mask_around_atoms(self, model, mask_atoms_atom_radius = None):
+  def create_mask_around_atoms(self, model, mask_atoms_atom_radius = None,
+      invert_mask = None):
     '''
       Use cctbx.maptbx.mask.create_mask_around_atoms to create a mask around
       atoms in model
@@ -849,6 +850,8 @@ class map_manager(map_reader, write_ccp4_map):
       Does not apply the mask (use apply_mask_to_map etc for that)
 
       mask_atoms_atom_radius default is max(3, resolution)
+
+      invert_mask makes outside 1 and inside 0
     '''
 
     assert model is not None
@@ -858,7 +861,8 @@ class map_manager(map_reader, write_ccp4_map):
     from cctbx.maptbx.mask import create_mask_around_atoms as cm
     self._created_mask = cm(map_manager = self,
       model = model,
-      mask_atoms_atom_radius = mask_atoms_atom_radius)
+      mask_atoms_atom_radius = mask_atoms_atom_radius,
+      invert_mask = invert_mask)
 
   def soft_mask(self, soft_mask_radius = None):
     '''
@@ -999,11 +1003,28 @@ class map_manager(map_reader, write_ccp4_map):
     assert isinstance(sites_cart, flex.vec3_double)
 
     from cctbx.maptbx import real_space_target_simple_per_site
-    return real_space_target_simple_per_site(
+    density_values = real_space_target_simple_per_site(
       unit_cell = self.crystal_symmetry().unit_cell(),
       density_map = self.map_data(),
       sites_cart = sites_cart)
 
+    # Cross off anything outside the box if wrapping is false
+    if not self.wrapping():
+      sites_frac = self.crystal_symmetry().unit_cell().fractionalize(sites_cart)
+      x,y,z = sites_frac.parts()
+      s = (
+         (x < 0) |
+         (y < 0) |
+         (z < 0) |
+         (x > 1) |
+         (y > 1) |
+         (z > 1)
+         )
+      density_values.set_selected(s,0)
+    return density_values
+
+
+
   def get_density_along_line(self,
       start_site = None,
       end_site = None,
@@ -1799,13 +1820,16 @@ class map_manager(map_reader, write_ccp4_map):
        return self._warning_message
 
   def set_mean_zero_sd_one(self):
-    ''' Function to normalize the map '''
+    '''
+     Function to normalize the map
+     If the map has a constant value, do nothing
+    '''
     map_data = self.map_data()
     map_data = map_data - flex.mean(map_data)
     sd = map_data.sample_standard_deviation()
-    assert sd != 0
-    map_data = map_data/sd
-    self.set_map_data(map_data)
+    if sd != 0:
+      map_data = map_data/sd
+      self.set_map_data(map_data)
 
   def ncs_cc(self):
     if hasattr(self,'_ncs_cc'):
@@ -2083,7 +2107,7 @@ class map_manager(map_reader, write_ccp4_map):
       n_real.append(int(target_n + 0.999))
     return n_real
 
-  def find_n_highest_grid_points_as_sites_cart(self, n = None,
+  def find_n_highest_grid_points_as_sites_cart(self, n = 0,
     n_tolerance = 0, max_tries = 100):
     '''
       Return the n highest grid points in the map as sites_cart
@@ -2135,7 +2159,6 @@ class map_manager(map_reader, write_ccp4_map):
 
     return sample_regs_obj.get_array(1)
 
-
   def trace_atoms_in_map(self,
        dist_min,
        n_atoms):
@@ -2155,8 +2178,8 @@ class map_manager(map_reader, write_ccp4_map):
      return working_map_manager.find_n_highest_grid_points_as_sites_cart(
           n = n_atoms)
 
-  def map_as_fourier_coefficients(self, d_min = None,
-     d_max = None):
+  def map_as_fourier_coefficients(self, d_min = None, d_max = None, box=True,
+     resolution_factor=1./3):
     '''
        Convert a map to Fourier coefficients to a resolution of d_min,
        if d_min is provided, otherwise box full of map coefficients
@@ -2172,18 +2195,39 @@ class map_manager(map_reader, write_ccp4_map):
        map_data and
        map_coefficients without changing origin.  Both are intended for use
        with map_data that has an origin at (0, 0, 0).
+
+       The map coefficients are always in space group P1.
     '''
     assert self.map_data()
     assert self.map_data().origin() == (0, 0, 0)
+    # Choose d_min and make sure it is bigger than smallest allowed
+    if(d_min is None and not box):
+      d_min = maptbx.d_min_from_map(
+        map_data  = self.map_data(),
+        unit_cell = self.crystal_symmetry().unit_cell(),
+        resolution_factor = resolution_factor)
+      print("\nResolution of map coefficients using "+\
+        "resolution_factor of %.2f: %.1f A\n" %(resolution_factor, d_min),
+        file=self.log)
+    elif (not box):  # make sure d_min is big enough
+      d_min_allowed = maptbx.d_min_from_map(
+        map_data  = self.map_data(),
+        unit_cell = self.crystal_symmetry().unit_cell(),
+        resolution_factor = 0.5)
+      if d_min < d_min_allowed:
+        print("\nResolution of map coefficients allowed by gridding is %.3f " %(
+          d_min_allowed),file=self.log)
+        d_min=d_min_allowed
+    from cctbx import crystal
+    crystal_symmetry = crystal.symmetry(
+      self.crystal_symmetry().unit_cell().parameters(), 1)
     ma = miller.structure_factor_box_from_map(
-      crystal_symmetry = self.crystal_symmetry(),
+      crystal_symmetry = crystal_symmetry,
       include_000      = True,
       map              = self.map_data(),
-      d_min            = d_min )
-    if d_max is not None:
-      ma=ma.resolution_filter(d_min = d_min, d_max = d_max)
-      # NOTE: miller array resolution_filter produces a new array.
-      # Methods in map_manager that are _filter() change the existing array.
+      d_min            = d_min)
+    if(d_max is not None):
+      ma = ma.resolution_filter(d_max = d_max)
     return ma
 
   def fourier_coefficients_as_map_manager(self, map_coeffs):
@@ -2206,7 +2250,7 @@ class map_manager(map_reader, write_ccp4_map):
     return self.customized_copy(
       map_data=maptbx.map_coefficients_to_map(
         map_coeffs       = map_coeffs,
-        crystal_symmetry = self.crystal_symmetry(),
+        crystal_symmetry = map_coeffs.crystal_symmetry(),
         n_real           = self.map_data().all())
       )
 
